@@ -13,11 +13,11 @@ String::Copyright - Representation of text-based copyright statements
 
 =head1 VERSION
 
-Version 0.001001
+Version 0.001002
 
 =cut
 
-our $VERSION = '0.001001';
+our $VERSION = '0.001002';
 
 # Dependencies
 use Exporter 5.57 (qw/import/);
@@ -125,19 +125,24 @@ sub normalize
 	new($self);
 }
 
-sub _compose { join "\n", @{ $_[0]->[BLOCKS] } }
+sub _compose
+{
+	join "\n", map { '© ' . $_ } @{ $_[0]->[BLOCKS] };
+}
 
 sub is_normalized { !defined $_[0]->[PLAINTEXT] }
 
+my $dash_re = qr{\s*[-˗‐‑‒–—―⁃−﹣－]\s*};
+
 sub parse_string
 {
 	my @block;
-	my $lines_after_copyright_block = 0;
+	my $skipped_lines = 0;
 
-	my $in_copyright_block = 0;
+	my $in_block = 0;
 	while (@_) {
 		my $line = shift;
-		my $copyright_match = parse_line( $line, \$in_copyright_block );
+		my $copyright_match = parse_line( $line, \$in_block );
 		if ($copyright_match) {
 			while ( @_ and $copyright_match =~ /\d[,.]?\s*$/ ) {
 
@@ -154,11 +159,11 @@ sub parse_string
 			# normalize year delimiters and ranges
 			# TODO: test if \K or non-backref beneficial on perl >= 5.10
 			#$copyright_match =~ s/\b\d{4}\K\s*,?\s*(?=\d{4}\b)/, /g;
-			#$copyright_match =~ s/\b\d{4}\K\s*-\s*(?=\d{4}\b)/-/g;
+			#$copyright_match =~ s/\b\d{4}\K$dash_re(?=\d{4}\b)/-/g;
 			#$copyright_match =~ s/\b(\d{4})\s*,?\s*(?=\d{4}\b)/$1, /g;
-			#$copyright_match =~ s/\b(\d{4})\s*-\s*(?=\d{4}\b)/$1-/g;
+			#$copyright_match =~ s/\b(\d{4})$dash_re(?=\d{4}\b)/$1-/g;
 			$copyright_match =~ s/\b(?<=\d{4})\s*,?\s*(?=\d{4}\b)/, /g;
-			$copyright_match =~ s/\b(?<=\d{4})\s*-\s*(?=\d{4}\b)/-/g;
+			$copyright_match =~ s/\b(?<=\d{4})$dash_re(?=\d{4}\b)/-/g;
 
 			# normalize years and year ranges
 			my $y;
@@ -192,60 +197,59 @@ sub parse_string
 
  # skip remaining lines if a copyright blocks was found more than 5 lines ago.
  # so a copyright block may contain up to 5 blank lines, but no more
-			last if $lines_after_copyright_block++ > 5;
+			last if $skipped_lines++ > 5;
 		}
 	}
 
-# TODO: save $lines_after_copyright_block to indicate how dirty parsing was
+# TODO: save $skipped_lines to indicate how dirty parsing was
 
 	return \@block;
 }
 
 # also used to cleanup
-my $copyright_indicator_regex = qr!
+my $sign_re = qr!
 	(?:copyright(?:-holders?)? # The full word (or slightly more)
-		|copr\. # Legally-valid abbreviation
-		|© # Unicode character COPYRIGHT SIGN
-		|\(c\) # Legally-null representation of sign
+		|copr\.            # Abbreviation legally valid in USA
+		|[©⒞Ⓒⓒ🄒🄫🅒]         # COPYRIGHT SIGN (and variations)
+		|\(c\)             # Legally-null representation of sign
 	)
 !ix;
 
-my $copyright_indicator_regex_with_capture
-	= qr!$copyright_indicator_regex(?::\s*|\s+)(\S.*)$!lix;
+my $sign_with_capture_re = qr!$sign_re(?::\s*|\s+)(\S.*)$!;
 
 # avoid ditching things like <info@foo.com>
-my $copyright_disindicator_regex = qr{
+my $not_owner_re = qr{
 	\b(?:info(?:rmation)?(?!@) # Discussing copyright information
-	|(:?notice|statement|claim|string)s? # Discussing the notice
+	|(?:notice|statement|claim|string)s? # Discussing the notice
 	|is|in|to # Part of a sentence
 	|(?:holder|owner)s? # Part of a sentence
 	|ownership # Part of a sentence
 	)\b
 }ix;
 
-my $copyright_predisindicator_regex = qr!(
+my $not_before_sign_re = qr!
 	^[#]define\s.*\(c\) # #define foo(c) -- not copyright
-)!ix;
+!ix;
 
 sub parse_line
 {
-	my $data                   = shift;
-	my $in_copyright_block_ref = shift;
-	my $copyright              = '';
+	my $data         = shift;
+	my $in_block_ref = shift;
+	my $copyright    = '';
 	my $match;
 
-	if ( $data !~ $copyright_predisindicator_regex ) {
+	if ( $data !~ $not_before_sign_re ) {
 
 		#print "match against ->$data<-\n";
-		if ( $data =~ $copyright_indicator_regex_with_capture ) {
-			$match                   = $1;
-			$$in_copyright_block_ref = 1;
+		if ( $data =~ $sign_with_capture_re ) {
+			$match         = $1;
+			$$in_block_ref = 1;
 
 			# Ignore lines matching "see foo for copyright information" etc.
-			if ( $match !~ $copyright_disindicator_regex ) {
+			if ( $match !~ $not_owner_re ) {
 
 				# De-cruft
-				$match =~ s/$copyright_indicator_regex//igx;
+				$match =~ s/$sign_re//g;
 				$match =~ s/^\s+//;
 				$match =~ s/\s*\bby\b\s*/ /;
 				$match =~ s/\s*$//;
@@ -253,14 +257,14 @@ sub parse_line
 				$copyright = $match;
 			}
 		}
-		elsif ( $$in_copyright_block_ref and $data =~ /^\d{2,}[,\s]+/ ) {
+		elsif ( $$in_block_ref and $data =~ /^\d{2,}[,\s]+/ ) {
 
 			# following lines beginning with a year are supposed to be
 			# continued copyright blocks
 			$copyright = $data;
 		}
 		else {
-			$$in_copyright_block_ref = 0;
+			$$in_block_ref = 0;
 		}
 	}
 	return $copyright;
